@@ -7,4 +7,5 @@ from Arbie.Actions.path_finder import PathFinder  # noqa: F401
 from Arbie.Actions.pool_finder import PoolFinder  # noqa: F401
 from Arbie.Actions.pool_updater import PoolUpdater  # noqa: F401
 from Arbie.Actions.redis_state import RedisState  # noqa: F401
-from Arbie.Actions.trader import Trader  # noqa: F401
+from Arbie.Actions.trader import LogTrader, SetUpTrader, Trader  # noqa: F401
+from Arbie.Actions.whitelist import Whitelist  # noqa: F401
