@@ -2,7 +2,7 @@
 import asyncio
 import logging
 from math import isclose
-from typing import List, Tuple
+from typing import List, Set, Tuple
 
 from prometheus_async.aio import time
 
@@ -29,8 +29,9 @@ def check_and_get_price(balances) -> Tuple[bool, float]:
 
 
 class TokenFinder(object):
-    def __init__(self, uoa):
+    def __init__(self, uoa, whitelist: Set[str]):
         self.uoa = uoa
+        self.whitelist = whitelist
 
     async def create_token(self, pair: UniswapPair, price):
         tokens = await pair.get_tokens()
@@ -42,7 +43,7 @@ class TokenFinder(object):
             return await t0.create_token(1 / price)
 
     @time(CREATE_TOKEN_TIME)
-    async def create_and_check_token(self, pair):
+    async def create_and_check_token(self, pair: UniswapPair) -> GenericToken:
         balances = None
         try:
             balances = await pair.get_balances()
@@ -57,13 +58,26 @@ class TokenFinder(object):
         logger.info(f"Finished creating token from {pair.get_address()}")
         return token
 
-    async def create_tokens(self, uniswap_pairs: List[UniswapPair]) -> List[Token]:
-        tokens = await async_map(self.create_and_check_token, uniswap_pairs)
+    async def create_tokens(self, pairs: List[UniswapPair]) -> List[Token]:
+        tokens = await async_map(self.create_and_check_token, pairs)
         tokens.append(self.uoa)
         token_set = set(tokens)
         token_set.discard(None)
         return list(token_set)
 
+    async def filter_pairs(self, pairs: List[UniswapPair]) -> List[UniswapPair]:
+        pairs = await async_map(self._filter_pair_in_whitelist, pairs)
+        pair_set = set(pairs)
+        pair_set.discard(None)
+        return list(pair_set)
+
+    async def _filter_pair_in_whitelist(self, pair: UniswapPair) -> UniswapPair:
+        tokens = await pair.get_tokens()
+        t0 = tokens[0].get_address().lower()
+        t1 = tokens[1].get_address().lower()
+        if t0 in self.whitelist and t1 in self.whitelist:
+            return pair
+
 
 async def create_and_filter_pools(
     pool_contracts: List[PoolContract], tokens: List[Tokens]
@@ -102,42 +116,45 @@ class PoolFinder(Action):
         uniswap_factory: uniswap_factory
         balancer_factory: balancer_factory
         balancer_start: 9562480
+        whitelist: addresses
     output:
         pools: all_pools
         tokens: all_tokens
     """
 
     async def on_next(self, data):
-        weth = data.weth()
+        weth = await data.weth().create_token(1)
 
-        uni_coro = self._get_pairs_and_tokens(data.uniswap_factory(), weth)
-        bal_coro = data.balancer_factory().all_pools(data.balancer_start(), 100)
+        uni_coro = self._get_pairs_and_tokens(
+            data.uniswap_factory(), TokenFinder(weth, set(data.whitelist()))
+        )
 
         pools, tokens = await self._get_pools_and_tokens(
-            *await self._get_results(uni_coro, bal_coro),
+            *await self._get_results(uni_coro),
         )
 
         data.pools(pools)
         data.tokens(tokens)
 
-    async def _get_pools_and_tokens(self, pool_contracts, pair_contracts, tokens):
+    async def _get_pools_and_tokens(self, pair_contracts, tokens):
         result = await asyncio.gather(
             create_and_filter_pools(pair_contracts, tokens),
-            create_and_filter_pools(pool_contracts, tokens),
         )
-        return result[0] + result[1], tokens
+        return result[0], tokens
 
     async def _get_results(
-        self, uni_coro, bal_coro
+        self, uni_coro
     ) -> Tuple[List[BalancerFactory], List[UniswapFactory], List[GenericToken]]:
-        results = await asyncio.gather(uni_coro, bal_coro)
-        pools = results[1]
+        results = await asyncio.gather(uni_coro)
         pairs = results[0][0]
         tokens = results[0][1]
-        return pools, pairs, tokens
+        return pairs, tokens
 
-    async def _get_pairs_and_tokens(self, factory: UniswapFactory, weth):
+    async def _get_pairs_and_tokens(
+        self, factory: UniswapFactory, token_finder: TokenFinder
+    ):
         pairs = await factory.all_pairs()
+        pairs = await token_finder.filter_pairs(pairs)
         logging.getLogger().info("Found all uniswap pairs, filtering tokens.")
-        tokens = await TokenFinder(weth).create_tokens(pairs)
+        tokens = await token_finder.create_tokens(pairs)
         return pairs, tokens
