@@ -1,11 +1,7 @@
 """Contracts enable interacton with ETH contracts."""
-from Arbie.Contracts.arbie import Arbie  # noqa: F401
 from Arbie.Contracts.balancer import BalancerFactory, BalancerPool  # noqa: F401
 from Arbie.Contracts.contract import Contract, ContractFactory, Network  # noqa: F401
 from Arbie.Contracts.event_filter import EventFilter  # noqa: F401
-from Arbie.Contracts.tokens import GenericToken, IERC20Token  # noqa: F401
-from Arbie.Contracts.uniswap import (  # noqa: F401
-    UniswapFactory,
-    UniswapPair,
-    UniswapV2Router,
-)
+from Arbie.Contracts.tokens import GenericToken, IERC20Token, Weth  # noqa: F401
+from Arbie.Contracts.uniswap import UniswapFactory, UniswapPair  # noqa: F401
+from Arbie.Contracts.uniswap_router import UniswapV2Router  # noqa: F401
