@@ -6,10 +6,12 @@ import logging
 from Arbie.Contracts.contract import Contract
 from Arbie.Variables import BigNumber, Token
 
+token_protocol = "tokens"  # noqa: S105
+
 
 class IERC20Token(Contract):
     name = "IERC20"
-    protocol = "tokens"
+    protocol = token_protocol
 
     def __eq__(self, other):
         return self.get_address() == other.get_address()
@@ -27,9 +29,12 @@ class IERC20Token(Contract):
         transaction = self.contract.functions.transfer(to, bg_number.value)
         return self._transact_status(transaction)
 
-    def approve(self, spender: str, bg_number: BigNumber, from_address=None) -> bool:
+    def allowance(self, to: str):
+        return self.contract.functions.allowance(self._get_account(), to).call()
+
+    def approve(self, spender: str, bg_number: BigNumber) -> bool:
         transaction = self.contract.functions.approve(spender, bg_number.value)
-        return self._transact_status(transaction, from_address)
+        return self._transact_status(transaction)
 
     async def approve_owner(self):
         bg = await self.balance_of(self.owner_address)
@@ -41,12 +46,12 @@ class IERC20Token(Contract):
 
 class BadERC20Token(IERC20Token):
     name = "BadERC20"
-    protocol = "tokens"
+    protocol = token_protocol
 
 
 class GenericToken(IERC20Token):
     name = "ERC20"
-    protocol = "tokens"
+    protocol = token_protocol
 
     def __str__(self):
         return (
@@ -71,3 +76,16 @@ class GenericToken(IERC20Token):
 
     def _name(self):
         return self.contract.functions.name()
+
+
+class Weth(GenericToken):
+    name = "Weth"
+    protocol = token_protocol
+
+    def deposit(self, amount):
+        transaction = self.contract.functions.deposit()
+        return self._transact_status(transaction, BigNumber(amount).value)
+
+    def withdraw(self, amount):
+        transaction = self.contract.functions.withdraw(BigNumber(amount).value)
+        return self._transact_status(transaction)
