@@ -29,11 +29,6 @@ async def create_reserve(result: Tuple[float, GenericToken]):
     return BigNumber.from_value(value, exp)
 
 
-class UniswapV2Router(Contract):
-    name = "UniswapV2Router02"
-    protocol = "uniswap"
-
-
 class UniswapPair(PoolContract):
     name = "UniswapV2Pair"
     protocol = "uniswap"
@@ -83,9 +78,9 @@ class UniswapFactory(Contract):
     name = "UniswapV2Factory"
     protocol = "uniswap"
 
-    def __init__(self, w3, owner_address: str, contract):
+    def __init__(self, w3, contract, **kwargs):
         self.cf = ContractFactory(w3, UniswapPair)
-        super().__init__(w3, owner_address, contract)
+        super().__init__(w3, contract, **kwargs)
 
     async def all_pairs_length(self) -> int:
         return await self._call_async(self.contract.functions.allPairsLength())
